#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 old-time
version:              1.1.1.0
visibility:           public
id:                   old-time-1.1.1.0-9WWjmNUa02UkaP5dbkbXm
key:                  old-time-1.1.1.0-9WWjmNUa02UkaP5dbkbXm
license:              BSD-3-Clause
maintainer:           https://github.com/haskell/old-time
synopsis:             Time library
description:
    This is a legacy package, please migrate away to
    <http://hackage.haskell.org/package/time time> or elsewhere.

category:             System
abi:                  6cc9973f8a6d542139a11293c5a633d0
exposed:              True
exposed-modules:      System.Time
import-dirs:          /usr/lib/ghc-9.6.6/site-local/old-time-1.1.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/old-time-1.1.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/old-time-1.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-old-time
hs-libraries:         HSold-time-1.1.1.0-9WWjmNUa02UkaP5dbkbXm
include-dirs:         /usr/lib/ghc-9.6.6/site-local/old-time-1.1.1.0/include
depends:
    base-4.18.2.1 old-locale-1.0.0.7-Gunit3UBy5P9OGDVFY5MhC

haddock-interfaces:   /usr/share/doc/haskell-old-time/html/old-time.haddock
haddock-html:         /usr/share/doc/haskell-old-time/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

